# soslyze

Summarize SysMgmt/Subscription Management/Insights data from an extracted sosreport archive.

Optionally call memory & CPU analysis from xsos.

### Usage:

```
usage: soslyze [-h] [path]

Summarize SysMgmt/Subscription Management/Insights data from an extracted sosreport archive.

positional arguments:
  path        Path to sosreport. Default: `./`.

options:
  -h, --help  show this help message and exit
```

----------------------------------------------------------

sosreport is an extensible, portable, support data collection tool primarily
aimed at Linux distributions and other UNIX-like operating systems.

The sosreport project is hosted at:

  * https://github.com/sosreport/sos
